sqlobject.tests.test_converters module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_converters module

class `sqlobject.tests.test_converters.` `NewSOTestClass`

  Bases: `object`

`sqlobject.tests.test_converters.` `NewSOTestClassConverter`(value, db)

class `sqlobject.tests.test_converters.` `SOTestClass`

  Bases: `object`

`sqlobject.tests.test_converters.` `SOTestClassConverter`(value, db)

`sqlobject.tests.test_converters.` `test_bool`()

`sqlobject.tests.test_converters.` `test_call`()

`sqlobject.tests.test_converters.` `test_constant`()

`sqlobject.tests.test_converters.` `test_datetime`()

`sqlobject.tests.test_converters.` `test_delete`()

`sqlobject.tests.test_converters.` `test_dict`()

`sqlobject.tests.test_converters.` `test_float`()

`sqlobject.tests.test_converters.` `test_insert`()

`sqlobject.tests.test_converters.` `test_instance`()

`sqlobject.tests.test_converters.` `test_integer`()

`sqlobject.tests.test_converters.` `test_like_quoted`()

`sqlobject.tests.test_converters.` `test_list`()

`sqlobject.tests.test_converters.` `test_newstyle`()

`sqlobject.tests.test_converters.` `test_none`()

`sqlobject.tests.test_converters.` `test_op`()

`sqlobject.tests.test_converters.` `test_prefix`()

`sqlobject.tests.test_converters.` `test_quote_unquote_str`()

`sqlobject.tests.test_converters.` `test_replace`()

`sqlobject.tests.test_converters.` `test_select`()

`sqlobject.tests.test_converters.` `test_sets`()

`sqlobject.tests.test_converters.` `test_simple_string`()

`sqlobject.tests.test_converters.` `test_simple_unicode`()

`sqlobject.tests.test_converters.` `test_sqlexpr`()

`sqlobject.tests.test_converters.` `test_sqlobjectfield`()

`sqlobject.tests.test_converters.` `test_string_`()

`sqlobject.tests.test_converters.` `test_string_000`()

`sqlobject.tests.test_converters.` `test_string_b`()

`sqlobject.tests.test_converters.` `test_string_newline`()

`sqlobject.tests.test_converters.` `test_string_r`()

`sqlobject.tests.test_converters.` `test_string_tab`()

`sqlobject.tests.test_converters.` `test_timedelta`()

`sqlobject.tests.test_converters.` `test_trueclause`()

`sqlobject.tests.test_converters.` `test_tuple`()

`sqlobject.tests.test_converters.` `test_update`()